@@ -12,11 +12,12 @@ from dhlab.legacy import (
 # code from further down in the code tree
 
 # text 
-from dhlab.text.corpus import Corpus, EmptyCorpus
+from dhlab.text.corpus import Corpus
 from dhlab.text.chunking import Chunks
 from dhlab.text.conc_coll import Collocations, Concordance, Counts
 from dhlab.text.geo_data import GeoData, GeoNames
 from dhlab.text.parse import NER, POS, Models
+from dhlab.text.wildcard import WildcardWordSearch
 
 # ngram 
 from dhlab.ngram.ngram import Ngram, NgramBook, NgramNews
